neuro_athelets
===============
contains:
    1. eeg_utilities -- for reading raw .eeg files. Requires amrk and ahdr existance at the same folder structure. 
    2. analytics_engine
        -- for rolling window analysis
        -- for fft
        -- for hierachical clustering
        -- for kmeans clustering
        -- for plotting 
